Coconut_
========

.. toctree::
   :maxdepth: 3

   FAQ
   HELP
   DOCS

Coconut is a variant of Python_ built for **simple, elegant, Pythonic functional programming**.

Coconut is developed on GitHub_ and hosted on PyPI_, where it has been downloaded `over 30,000 times <http://pypi-ranking.info/module/coconut>`_. Installing Coconut is as easy as opening a command prompt and entering::

    python -m pip install coconut

after which the entire world of Coconut will be at your disposal. To help you get started, check out these links for more information about Coconut:

- Help_: If you're new to Coconut, Coconut's Help provides a **straightforward, easy-to-follow tutorial** of the Coconut Programming Language.
- Docs_: If you're looking for info about a specific feature, Coconut's Docs provide a **complete documentation** of the language.
- FAQ_: If you have questions about who Coconut is built for and whether or not you should use it, Coconut's frequently asked questions have you covered.
- `Create a New Issue <https://github.com/evhub/coconut/issues/new>`_: If you're having a problem with Coconut, creating a new issue detailing the problem will allow it to be addressed as soon as possible.
- Gitter_: For all general questions, concerns, or comments about anything Coconut-related, ask around at Coconut's Gitter, a GitHub-integrated chat room for Coconut developers.

*Note: If the above documentation links are not working, try the* |mirror|_ *.*

.. _Coconut: http://evhub.github.io/coconut/
.. _Python: https://www.python.org/
.. _PyPI: https://pypi.python.org/pypi/coconut
.. _Help: http://coconut.readthedocs.org/en/master/HELP.html
.. _Docs: http://coconut.readthedocs.org/en/master/DOCS.html
.. _FAQ: http://coconut.readthedocs.org/en/master/FAQ.html
.. _GitHub: https://github.com/evhub/coconut
.. _Gitter: https://gitter.im/evhub/coconut
.. _mirror: http://pythonhosted.org/coconut/
.. |mirror| replace:: *mirror*
